"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.Rename = void 0;
const common_1 = require("./common");
const fs_extra_1 = require("fs-extra");
class Rename extends common_1.Common {
    async exec(api, _options, args) {
        const [type, oldPath, newPath] = args;
        if (!type || !oldPath || !newPath) {
            this.throwInvalidateError();
        }
        this.projectPath = api.getCwd();
        const oldFileInfo = this.setFileInfo(oldPath);
        const newFileInfo = this.setFileInfo(newPath);
        const oldConfig = await this.setConfig(oldFileInfo.fileName);
        const newConfig = await this.setConfig(newFileInfo.fileName, true);
        const oldFiles = oldConfig[type];
        const newFiles = newConfig[type];
        this.renameFiles(oldFiles, newFiles);
    }
    renameFiles(oldFiles, newFiles) {
        oldFiles.files.forEach((file, index) => {
            const { filePath: oldFilePath, fileDir: oldFileDir } = this.constructFilePath(file);
            const { filePath: newFilePath, fileDir: newFileDir } = this.constructFilePath(newFiles.files[index]);
            if (fs_extra_1.existsSync(oldFilePath)) {
                fs_extra_1.ensureDirSync(newFileDir);
                fs_extra_1.renameSync(oldFilePath, newFilePath);
                this.deleteDir(oldFileDir);
                this.log('success', `Renamed: ${oldFilePath} -> ${newFilePath}`);
            }
            else {
                this.log('error', `File not exists to rename: ${oldFilePath} -> ${newFilePath}`);
            }
        });
    }
}
exports.Rename = Rename;
